@@ -1,6 +1,7 @@
 from bluer_ugv.help.swallow.dataset import help_functions as help_dataset
 from bluer_ugv.help.swallow.debug import help_debug
 from bluer_ugv.help.swallow.env import help_functions as help_env
+from bluer_ugv.help.swallow.keyboard import help_functions as help_keyboard
 from bluer_ugv.help.swallow.select_target import help_select_target
 from bluer_ugv.help.swallow.ultrasonic_sensor import (
     help_functions as help_ultrasonic_sensor,
@@ -10,6 +11,7 @@ help_functions = {
     "dataset": help_dataset,
     "debug": help_debug,
     "env": help_env,
+    "keyboard": help_keyboard,
     "select_target": help_select_target,
     "ultrasonic": help_ultrasonic_sensor,
 }
